@@ -83,6 +83,17 @@ test 'cart tests' => sub {
     throws_ok { $cart->add('this sku does not exist') }
     qr/Product with sku .+ does not exist/, "add sku that does not exist in db";
 
+    # variant
+    lives_ok { $ret = $cart->add('os28085-6') } "add variant os28085-6";
+    isa_ok( $ret->[0], 'Interchange6::Cart::Product' );
+    cmp_ok( $ret->[0]->sku, 'eq', 'os28085-6', "Check sku" );
+    cmp_ok( $ret->[0]->canonical_sku, 'eq', 'os28085', "Check canonical_sku" );
+    ok( $ret->[0]->is_variant, "product is a variant" );
+    ok( !$ret->[0]->is_canonical, "product is not canonical" );
+    lives_ok( sub { $cart->clear }, "clear the cart" );
+    cmp_ok( $cart->count, '==', 0,
+        "Check number of products in the cart is 0" );
+
     # add os28005 as scalar
     lives_ok { $ret = $cart->add('os28005') } "add single scalar sku";
     isa_ok( $ret->[0], 'Interchange6::Cart::Product' );
@@ -95,6 +106,8 @@ test 'cart tests' => sub {
         '==', 8.99, "Check price of returned product" );
     cmp_ok( $ret->[0]->quantity, '==', 1,
         "Check quantity of returned product is 1" );
+    ok( $ret->[0]->is_canonical, "product is canonical" );
+    ok( !$ret->[0]->is_variant, "product is not a variant" );
     cmp_ok( $cart->count, '==', 1,
         "Check number of products in the cart is 1" );
     cmp_ok( sprintf( "%.2f", $cart->subtotal ),
@@ -302,16 +315,25 @@ test 'cart tests' => sub {
 
     # Seed
 
+    lives_ok( sub { var ic6_carts => undef },
+        "undef var ic6_carts so new cart will not come from cache" );
+
     lives_ok { $cart = cart } "Create a new cart";
     cmp_ok( $cart->id, '==', 3, "cart id is 3" );
 
-    $log = pop @{&read_logs};
+    $log = &read_logs;
     cmp_deeply(
         $log,
-        { level => "debug", message => "New cart 3 main." },
+        [
+            { level => "debug", message => "carts_var_name: ic6_carts" },
+            { level => "debug", message => "New cart 3 main." },
+        ],
         "Check cart BUILDARGS debug message"
     ) or diag Dumper($log);
 
+    lives_ok { $cart = cart } "calling cart again should return same cart";
+    cmp_ok( $cart->id, '==', 3, "cart id is 3" );
+
     $ret = $schema->resultset('Cart')->search( {}, { order_by => 'carts_id' } );
     cmp_ok( $ret->count, '==', 3, "3 carts in the database" );
 
@@ -356,6 +378,43 @@ test 'cart tests' => sub {
 
     cmp_ok( $schema->resultset('Cart')->count, '==', 0, "0 Cart rows" );
 
+    # plugin setting carts_var_name
+    
+    setting('plugins')->{Interchange6}->{carts_var_name} = "foobar";
+
+    &read_logs;
+
+    lives_ok { $cart = cart } "Create a new cart";
+
+    $log = &read_logs;
+    cmp_deeply(
+        $log,
+        [
+            { level => "debug", message => "carts_var_name: foobar" },
+            { level => "debug", message => re('New cart \d+ main') },
+        ],
+        "Check cart BUILDARGS debug message"
+    ) or diag Dumper($log);
+
+    # subclassed cart
+
+    setting('plugins')->{Interchange6}->{carts_var_name} = "ic6_carts";
+    setting('plugins')->{Interchange6}->{cart_class} = "TestCart";
+
+    lives_ok( sub { var ic6_carts => undef },
+        "undef var ic6_carts so new cart will not come from cache" );
+
+    lives_ok( sub { $cart = cart("test") }, "get new TestCart with name test" );
+
+    isa_ok( $cart, 'TestCart' );
+    isa_ok( $cart, 'Interchange6::Cart' );
+    ok( $cart->can('add'), "has add method" );
+    ok( $cart->can('test_method'), "has test_method" );
+    cmp_ok( $cart->name, 'eq', 'test', "name is test" );
+    ok( ! defined $cart->test_attribute, "test_attribute is undef" );
+    lives_ok( sub { $cart->test_attribute("foobar") }, "set test_attribute" );
+    cmp_ok( $cart->test_attribute, 'eq', 'foobar', "has test_attribute" );
+
 };
 
 1;
